==> lvm-0.3alpha.tar.gz: LVM/0.3alpha/tools/lib/vg_set_clear_extendable.c <==
/*
 * Author: Heinz Mauelshagen, Germany
 *
 * May 1998
 *
 * LVM is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * LVM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU CC; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA. 
 *
 */

#include <liblvm.h>

/* internal function */
int vg_set_clear_extendable ( char*, int);


int vg_set_extendable ( char *vg_name) {
   return vg_set_clear_extendable ( vg_name, VG_EXTENDABLE);
}

int vg_clear_extendable ( char *vg_name) {
   return vg_set_clear_extendable ( vg_name, ~VG_EXTENDABLE);
}


int vg_set_clear_extendable ( char *vg_name, int what) {
   int group = -1;
   int ret = 0;
   char group_file[NAME_LEN];

#ifdef DEBUG
   debug ( "vg_set_clear_extendable -- CALLED\n");
#endif

   if ( vg_name == NULL || vg_check_name ( vg_name) < 0) return -LVM_EPARA;

   sprintf ( group_file, "/dev/%s/group%c", vg_name, 0);
   if ( ( group = open ( group_file, O_RDWR)) == -1)
      ret = -LVM_EVG_SET_CLEAR_EXTENDABLE_OPEN;
   else {
#ifdef DEBUG
      debug ( "vg_set_clear_extendable -- IOCTL\n");
#endif
      if ( ( ret = ioctl ( group, VG_SET_EXTENDABLE, &what)) == -1)
         ret = -errno;;
#ifdef DEBUG
      debug ( "vg_set_clear_extendable -- IOCTL returned: %d\n", ret);
#endif
   }

   if ( group != -1) close ( group);

#ifdef DEBUG
   debug ( "vg_set_clear_extendable -- CALLED\n");
#endif
   return ret;
}

==> lvm-0.4alpha.tar.gz: LVM/0.4alpha/tools/lib/vg_set_clear_extendable.c <==
/*
 * Author: Heinz Mauelshagen, Germany
 *
 * May 1998
 *
 * LVM is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * LVM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU CC; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA. 
 *
 */

#include <liblvm.h>

/* internal function */
int vg_set_clear_extendable ( char*, int);


int vg_set_extendable ( char *vg_name) {
   return vg_set_clear_extendable ( vg_name, VG_EXTENDABLE);
}

int vg_clear_extendable ( char *vg_name) {
   return vg_set_clear_extendable ( vg_name, ~VG_EXTENDABLE);
}


int vg_set_clear_extendable ( char *vg_name, int what) {
   int group = -1;
   int ret = 0;
   char group_file[NAME_LEN];

#ifdef DEBUG
   debug ( "vg_set_clear_extendable -- CALLED\n");
#endif

   if ( vg_name == NULL || vg_check_name ( vg_name) < 0) return -LVM_EPARAM;

   sprintf ( group_file, "/dev/%s/group%c", vg_name, 0);
   if ( ( group = open ( group_file, O_RDWR)) == -1)
      ret = -LVM_EVG_SET_CLEAR_EXTENDABLE_OPEN;
   else {
#ifdef DEBUG
      debug ( "vg_set_clear_extendable -- IOCTL\n");
#endif
      if ( ( ret = ioctl ( group, VG_SET_EXTENDABLE, &what)) == -1)
         ret = -errno;;
#ifdef DEBUG
      debug ( "vg_set_clear_extendable -- IOCTL returned: %d\n", ret);
#endif
   }

   if ( group != -1) close ( group);

#ifdef DEBUG
   debug ( "vg_set_clear_extendable -- CALLED\n");
#endif
   return ret;
}
